@@ -27,7 +27,9 @@ def user_exists(name):
     return (res == "1")
 
 
-def create_user(name, password):
+def create_user(name, password, superuser=False, createdb=False,
+    createrole=False, inherit=True, login=True, connection_limit=None,
+    encrypted_password=False):
     """
     Create a PostgreSQL user.
 
@@ -39,8 +41,24 @@ def create_user(name, password):
         if not fabtools.postgres.user_exists('dbuser'):
             fabtools.postgres.create_user('dbuser', password='somerandomstring')
 
+        # Create DB user with custom options
+        fabtools.postgres.create_user('dbuser2', password='s3cr3t',
+            createdb=True, createrole=True, connection_limit=20)
+
     """
-    _run_as_pg('''psql -c "CREATE USER %(name)s WITH PASSWORD '%(password)s';"''' % locals())
+    options = [
+        'SUPERUSER' if superuser else 'NOSUPERUSER',
+        'CREATEDB' if createdb else 'NOCREATEDB',
+        'CREATEROLE' if createrole else 'NOCREATEROLE',
+        'INHERIT' if inherit else 'NOINHERIT',
+        'LOGIN' if login else 'NOLOGIN',
+    ]
+    if connection_limit is not None:
+        options.append('CONNECTION LIMIT %d' % connection_limit)
+    password_type = 'ENCRYPTED' if encrypted_password else 'UNENCRYPTED'
+    options.append("%s PASSWORD '%s'" % (password_type, password))
+    options = ' '.join(options)
+    _run_as_pg('''psql -c "CREATE USER %(name)s %(options)s;"''' % locals())
 
 
 def database_exists(name):
