@@ -1,5 +1,6 @@
 """
-Fabric tools for managing system settings
+System settings
+===============
 """
 from __future__ import with_statement
 
@@ -8,7 +9,7 @@ from fabric.api import *
 
 def get_hostname():
     """
-    Get the fully qualified hostname
+    Get the fully qualified hostname.
     """
     with settings(hide('running', 'stdout')):
         return run('hostname --fqdn')
@@ -16,7 +17,7 @@ def get_hostname():
 
 def set_hostname(hostname, persist=True):
     """
-    Set the hostname
+    Set the hostname.
     """
     sudo('hostname %s' % hostname)
     if persist:
@@ -25,7 +26,14 @@ def set_hostname(hostname, persist=True):
 
 def get_sysctl(key):
     """
-    Get a kernel parameter
+    Get a kernel parameter.
+
+    Example::
+
+        from fabtools.system import get_sysctl
+
+        print "Max number of open files:", get_sysctl('fs.file-max')
+
     """
     with settings(hide('running', 'stdout')):
         return sudo('/sbin/sysctl -n -e %(key)s' % locals())
@@ -33,16 +41,24 @@ def get_sysctl(key):
 
 def set_sysctl(key, value):
     """
-    Set a kernel parameter
+    Set a kernel parameter.
+
+    Example::
+
+        import fabtools
+
+        # Protect from SYN flooding attack
+        fabtools.system.set_sysctl('net.ipv4.tcp_syncookies', 1)
+
     """
     sudo('/sbin/sysctl -n -e -w %(key)s=%(value)s' % locals())
 
 
 def supported_locales():
     """
-    Gets the list of supported locales
+    Gets the list of supported locales.
 
-    Each locale is returned as a (locale, charset) tuple
+    Each locale is returned as a ``(locale, charset)`` tuple.
     """
     with settings(hide('running', 'stdout')):
         res = run('grep -v "^#" /usr/share/i18n/SUPPORTED')
